@@ -101,6 +101,7 @@ struct Options
         , sectionsOnly(false)
         , protectedAuthenticationPath(false)
         , installApk(false)
+        , uninstallApk(false)
         , fetchedRemoteModificationDates(false)
     {}
 
@@ -125,6 +126,7 @@ struct Options
 
     // External tools
     QString sdkPath;
+    QString sdkBuildToolsVersion;
     QString ndkPath;
     QString antTool;
     QString jdkPath;
@@ -170,6 +172,7 @@ struct Options
 
     // Installation information
     bool installApk;
+    bool uninstallApk;
     QString installLocation;
 
     // Collected information
@@ -186,6 +189,78 @@ struct Options
     QStringList features;
 };
 
+// Copy-pasted from qmake/library/ioutil.cpp
+inline static bool hasSpecialChars(const QString &arg, const uchar (&iqm)[16])
+{
+    for (int x = arg.length() - 1; x >= 0; --x) {
+        ushort c = arg.unicode()[x].unicode();
+        if ((c < sizeof(iqm) * 8) && (iqm[c / 8] & (1 << (c & 7))))
+            return true;
+    }
+    return false;
+}
+
+static QString shellQuoteUnix(const QString &arg)
+{
+    // Chars that should be quoted (TM). This includes:
+    static const uchar iqm[] = {
+        0xff, 0xff, 0xff, 0xff, 0xdf, 0x07, 0x00, 0xd8,
+        0x00, 0x00, 0x00, 0x38, 0x01, 0x00, 0x00, 0x78
+    }; // 0-32 \'"$`<>|;&(){}*?#!~[]
+
+    if (!arg.length())
+        return QString::fromLatin1("\"\"");
+
+    QString ret(arg);
+    if (hasSpecialChars(ret, iqm)) {
+        ret.replace(QLatin1Char('\''), QLatin1String("'\\''"));
+        ret.prepend(QLatin1Char('\''));
+        ret.append(QLatin1Char('\''));
+    }
+    return ret;
+}
+
+static QString shellQuoteWin(const QString &arg)
+{
+    // Chars that should be quoted (TM). This includes:
+    // - control chars & space
+    // - the shell meta chars "&()<>^|
+    // - the potential separators ,;=
+    static const uchar iqm[] = {
+        0xff, 0xff, 0xff, 0xff, 0x45, 0x13, 0x00, 0x78,
+        0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x10
+    };
+
+    if (!arg.length())
+        return QString::fromLatin1("\"\"");
+
+    QString ret(arg);
+    if (hasSpecialChars(ret, iqm)) {
+        // Quotes are escaped and their preceding backslashes are doubled.
+        // It's impossible to escape anything inside a quoted string on cmd
+        // level, so the outer quoting must be "suspended".
+        ret.replace(QRegExp(QLatin1String("(\\\\*)\"")), QLatin1String("\"\\1\\1\\^\"\""));
+        // The argument must not end with a \ since this would be interpreted
+        // as escaping the quote -- rather put the \ behind the quote: e.g.
+        // rather use "foo"\ than "foo\"
+        int i = ret.length();
+        while (i > 0 && ret.at(i - 1) == QLatin1Char('\\'))
+            --i;
+        ret.insert(i, QLatin1Char('"'));
+        ret.prepend(QLatin1Char('"'));
+    }
+    return ret;
+}
+
+static QString shellQuote(const QString &arg)
+{
+    if (QDir::separator() == QLatin1Char('\\'))
+        return shellQuoteWin(arg);
+    else
+        return shellQuoteUnix(arg);
+}
+
+
 Options parseOptions()
 {
     Options options;
@@ -205,6 +280,10 @@ Options parseOptions()
                 options.inputFileName = arguments.at(++i);
         } else if (argument.compare(QLatin1String("--install"), Qt::CaseInsensitive) == 0) {
             options.installApk = true;
+            options.uninstallApk = true;
+        } else if (argument.compare(QLatin1String("--reinstall"), Qt::CaseInsensitive) == 0) {
+            options.installApk = true;
+            options.uninstallApk = false;
         } else if (argument.compare(QLatin1String("--android-platform"), Qt::CaseInsensitive) == 0) {
             if (i + 1 == arguments.size())
                 options.helpRequested = true;
@@ -341,7 +420,12 @@ void printHelp()
                     "       ministro: Use the Ministro service to manage Qt files.\n"
                     "       debug: Copy Qt files to device for quick debugging.\n"
                     "    --install: Installs apk to device/emulator. By default this step is\n"
-                    "       not taken.\n"
+                    "       not taken. If the application has previously been installed on\n"
+                    "       the device, it will be uninstalled first.\n"
+                    "    --reinstall: Installs apk to device/emulator. By default this step\n"
+                    "       is not taken. If the application has previously been installed on\n"
+                    "       the device, it will be overwritten, but its data will be left\n"
+                    "       intact.\n"
                     "    --device [device ID]: Use specified device for deployment. Default\n"
                     "       is the device selected by default by adb.\n"
                     "    --android-platform <platform>: Builds against the given android\n"
@@ -551,12 +635,19 @@ bool readInputFile(Options *options)
                 return false;
         } else {
             if (!QDir(options->sdkPath + QLatin1String("/platforms/") + options->androidPlatform).exists()) {
-                fprintf(stderr, "Warning: Android platform '%s' does not exist in NDK.\n",
+                fprintf(stderr, "Warning: Android platform '%s' does not exist in SDK.\n",
                         qPrintable(options->androidPlatform));
             }
         }
     }
 
+    {
+
+        QJsonValue value = jsonObject.value("sdkBuildToolsRevision");
+        if (!value.isUndefined())
+            options->sdkBuildToolsVersion = value.toString();
+    }
+
     {
         QJsonValue qtInstallDirectory = jsonObject.value("qt");
         if (qtInstallDirectory.isUndefined()) {
@@ -1059,10 +1150,8 @@ bool updateAndroidFiles(Options &options)
 QStringList findFilesRecursively(const Options &options, const QString &fileName)
 {
     QFileInfo info(options.qtInstallDirectory + QLatin1Char('/') + fileName);
-    if (!info.exists()) {
-        fprintf(stderr, "Warning: Dependency not found: %s\n", qPrintable(info.filePath()));
+    if (!info.exists())
         return QStringList();
-    }
 
     if (info.isDir()) {
         QStringList ret;
@@ -1196,7 +1285,7 @@ QStringList getQtLibsFromElf(const Options &options, const QString &fileName)
         return QStringList();
     }
 
-    readElf = QString::fromLatin1("\"%1\" -d -W %2").arg(readElf).arg(fileName);
+    readElf = QString::fromLatin1("%1 -d -W %2").arg(shellQuote(readElf)).arg(shellQuote(fileName));
 
     FILE *readElfCommand = openProcess(readElf);
     if (readElfCommand == 0) {
@@ -1283,6 +1372,17 @@ bool readDependencies(Options *options)
     if (!readDependenciesFromElf(options, options->applicationBinary, &usedDependencies, &remainingDependencies))
         return false;
 
+    // Until we have support non-gui applications on Android, always add Qt Gui
+    // as a dependency (otherwise the platform plugin cannot be deployed, and
+    // the application will not run).
+    QLatin1String guiLib("lib/libQt5Gui.so");
+    if (!options->qtDependencies.contains(guiLib)) {
+        options->qtDependencies.append(guiLib);
+        usedDependencies.insert(guiLib);
+        if (!readAndroidDependencyXml(options, QLatin1String("Qt5Gui"), &usedDependencies, &remainingDependencies))
+            return false;
+    }
+
     QString qtDir = options->qtInstallDirectory + QLatin1Char('/');
 
     while (!remainingDependencies.isEmpty()) {
@@ -1340,7 +1440,7 @@ bool stripFile(const Options &options, const QString &fileName)
         return false;
     }
 
-    strip = QString::fromLatin1("\"%1\" %2").arg(strip).arg(fileName);
+    strip = QString::fromLatin1("%1 %2").arg(shellQuote(strip)).arg(shellQuote(fileName));
 
     FILE *stripCommand = openProcess(strip);
     if (stripCommand == 0) {
@@ -1416,9 +1516,9 @@ FILE *runAdb(const Options &options, const QString &arguments)
     }
     QString installOption;
     if (!options.installLocation.isEmpty())
-        installOption = QLatin1String(" -s ") + options.installLocation;
+        installOption = QLatin1String(" -s ") + shellQuote(options.installLocation);
 
-    adb = QString::fromLatin1("\"%1\"%2 %3").arg(adb).arg(installOption).arg(arguments);
+    adb = QString::fromLatin1("%1%2 %3").arg(shellQuote(adb)).arg(installOption).arg(arguments);
 
     if (options.verbose)
         fprintf(stdout, "Running command \"%s\"\n", adb.toLocal8Bit().constData());
@@ -1436,7 +1536,7 @@ bool fetchRemoteModifications(Options *options, const QString &directory)
 {
     options->fetchedRemoteModificationDates = true;
 
-    FILE *adbCommand = runAdb(*options, QLatin1String(" shell cat ") + directory + QLatin1String("/modification.txt"));
+    FILE *adbCommand = runAdb(*options, QLatin1String(" shell cat ") + shellQuote(directory + QLatin1String("/modification.txt")));
     if (adbCommand == 0)
         return false;
 
@@ -1448,7 +1548,7 @@ bool fetchRemoteModifications(Options *options, const QString &directory)
     pclose(adbCommand);
 
     if (options->qtInstallDirectory != qtPath) {
-        adbCommand = runAdb(*options, QLatin1String(" shell rm -r ") + directory);
+        adbCommand = runAdb(*options, QLatin1String(" shell rm -r ") + shellQuote(directory));
         if (options->verbose) {
             fprintf(stdout, "  -- Removing old Qt libs.\n");
             while (fgets(buffer, sizeof(buffer), adbCommand) != 0)
@@ -1457,7 +1557,7 @@ bool fetchRemoteModifications(Options *options, const QString &directory)
         pclose(adbCommand);
     }
 
-    adbCommand = runAdb(*options, QLatin1String(" ls ") + directory);
+    adbCommand = runAdb(*options, QLatin1String(" ls ") + shellQuote(directory));
     if (adbCommand == 0)
         return false;
 
@@ -1636,25 +1736,53 @@ bool copyQtFiles(Options *options)
     return true;
 }
 
+QStringList getLibraryProjectsInOutputFolder(const Options &options)
+{
+    QStringList ret;
+
+    QFile file(options.outputDirectory + QLatin1String("/project.properties"));
+    if (file.open(QIODevice::ReadOnly)) {
+        while (!file.atEnd()) {
+            QByteArray line = file.readLine().trimmed();
+            if (line.startsWith("android.library.reference")) {
+                int equalSignIndex = line.indexOf('=');
+                if (equalSignIndex >= 0) {
+                    QString path = QString::fromLocal8Bit(line.mid(equalSignIndex + 1));
+
+                    QFileInfo info(options.outputDirectory + QLatin1Char('/') + path);
+                    if (QDir::isRelativePath(path)
+                            && info.exists()
+                            && info.isDir()
+                            && info.canonicalFilePath().startsWith(options.outputDirectory)) {
+                        ret += info.canonicalFilePath();
+                    }
+                }
+            }
+        }
+    }
+
+    return ret;
+}
+
 bool createAndroidProject(const Options &options)
 {
     if (options.verbose)
         fprintf(stdout, "Running Android tool to create package definition.\n");
 
-    QString androidTool = options.sdkPath + QLatin1String("/tools/android");
+    QString androidToolExecutable = options.sdkPath + QLatin1String("/tools/android");
 #if defined(Q_OS_WIN32)
-    androidTool += QLatin1String(".bat");
+    androidToolExecutable += QLatin1String(".bat");
 #endif
 
-    if (!QFile::exists(androidTool)) {
-        fprintf(stderr, "Cannot find Android tool: %s\n", qPrintable(androidTool));
+    if (!QFile::exists(androidToolExecutable)) {
+        fprintf(stderr, "Cannot find Android tool: %s\n", qPrintable(androidToolExecutable));
         return false;
     }
 
-    androidTool = QString::fromLatin1("\"%1\" update project --path %2 --target %3 --name QtApp")
-            .arg(androidTool)
-            .arg(options.outputDirectory)
-            .arg(options.androidPlatform);
+    QString androidTool = QString::fromLatin1("%1 update project --path %2 --target %3 --name QtApp")
+                            .arg(shellQuote(androidToolExecutable))
+                            .arg(shellQuote(options.outputDirectory))
+                            .arg(shellQuote(options.androidPlatform));
 
     if (options.verbose)
         fprintf(stdout, "  -- Command: %s\n", qPrintable(androidTool));
@@ -1667,6 +1795,29 @@ bool createAndroidProject(const Options &options)
 
     pclose(androidToolCommand);
 
+    // If the project has subprojects inside the current folder, we need to also run android update on these.
+    QStringList libraryProjects = getLibraryProjectsInOutputFolder(options);
+    foreach (QString libraryProject, libraryProjects) {
+        if (options.verbose)
+            fprintf(stdout, "Updating subproject %s\n", qPrintable(libraryProject));
+
+        androidTool = QString::fromLatin1("%1 update lib-project --path %2 --target %3")
+                .arg(shellQuote(androidToolExecutable))
+                .arg(shellQuote(libraryProject))
+                .arg(shellQuote(options.androidPlatform));
+
+        if (options.verbose)
+            fprintf(stdout, "  -- Command: %s\n", qPrintable(androidTool));
+
+        FILE *androidToolCommand = popen(androidTool.toLocal8Bit().constData(), "r");
+        if (androidToolCommand == 0) {
+            fprintf(stderr, "Cannot run command '%s'\n", qPrintable(androidTool));
+            return false;
+        }
+
+        pclose(androidToolCommand);
+    }
+
     return true;
 }
 
@@ -1717,7 +1868,7 @@ bool buildAndroidProject(const Options &options)
         return false;
     }
 
-    QString ant = QString::fromLatin1("\"%1\" %2").arg(antTool).arg(options.releasePackage ? QLatin1String(" release") : QLatin1String(" debug"));
+    QString ant = QString::fromLatin1("%1 %2").arg(shellQuote(antTool)).arg(options.releasePackage ? QLatin1String(" release") : QLatin1String(" debug"));
 
     FILE *antCommand = openProcess(ant);
     if (antCommand == 0) {
@@ -1751,7 +1902,7 @@ bool uninstallApk(const Options &options)
         fprintf(stdout, "Uninstalling old Android package %s if present.\n", qPrintable(options.packageName));
 
 
-    FILE *adbCommand = runAdb(options, QLatin1String(" uninstall ") + options.packageName);
+    FILE *adbCommand = runAdb(options, QLatin1String(" uninstall ") + shellQuote(options.packageName));
     if (adbCommand == 0)
         return false;
 
@@ -1786,17 +1937,18 @@ QString apkName(const Options &options)
 bool installApk(const Options &options)
 {
     // Uninstall if necessary
-    uninstallApk(options);
+    if (options.uninstallApk)
+        uninstallApk(options);
 
     if (options.verbose)
         fprintf(stdout, "Installing Android package to device.\n");
 
     FILE *adbCommand = runAdb(options,
                               QLatin1String(" install -r ")
-                              + options.outputDirectory
-                              + QLatin1String("/bin/")
-                              + apkName(options)
-                              + QLatin1String(".apk"));
+                              + shellQuote(options.outputDirectory)
+                              + shellQuote(QLatin1String("/bin/")
+                                + apkName(options)
+                                + QLatin1String(".apk")));
     if (adbCommand == 0)
         return false;
 
@@ -1876,29 +2028,29 @@ bool signPackage(const Options &options)
         return false;
     }
 
-    jarSignerTool = QString::fromLatin1("\"%1\" -sigalg \"%2\" -digestalg \"%3\" -keystore \"%4\"")
-            .arg(jarSignerTool).arg(options.sigAlg).arg(options.digestAlg).arg(options.keyStore);
+    jarSignerTool = QString::fromLatin1("%1 -sigalg %2 -digestalg %3 -keystore %4")
+            .arg(shellQuote(jarSignerTool)).arg(shellQuote(options.sigAlg)).arg(shellQuote(options.digestAlg)).arg(shellQuote(options.keyStore));
 
     if (!options.keyStorePassword.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -storepass \"%1\"").arg(options.keyStorePassword);
+        jarSignerTool += QString::fromLatin1(" -storepass %1").arg(shellQuote(options.keyStorePassword));
 
     if (!options.storeType.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -storetype \"%1\"").arg(options.storeType);
+        jarSignerTool += QString::fromLatin1(" -storetype %1").arg(shellQuote(options.storeType));
 
     if (!options.keyPass.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -keypass \"%1\"").arg(options.keyPass);
+        jarSignerTool += QString::fromLatin1(" -keypass %1").arg(shellQuote(options.keyPass));
 
     if (!options.sigFile.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -sigfile \"%1\"").arg(options.sigFile);
+        jarSignerTool += QString::fromLatin1(" -sigfile %1").arg(shellQuote(options.sigFile));
 
     if (!options.signedJar.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -signedjar \"%1\"").arg(options.signedJar);
+        jarSignerTool += QString::fromLatin1(" -signedjar %1").arg(shellQuote(options.signedJar));
 
     if (!options.tsaUrl.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -tsa \"%1\"").arg(options.tsaUrl);
+        jarSignerTool += QString::fromLatin1(" -tsa %1").arg(shellQuote(options.tsaUrl));
 
     if (!options.tsaCert.isEmpty())
-        jarSignerTool += QString::fromLatin1(" -tsacert \"%1\"").arg(options.tsaCert);
+        jarSignerTool += QString::fromLatin1(" -tsacert %1").arg(shellQuote(options.tsaCert));
 
     if (options.internalSf)
         jarSignerTool += QLatin1String(" -internalsf");
@@ -1909,12 +2061,12 @@ bool signPackage(const Options &options)
     if (options.protectedAuthenticationPath)
         jarSignerTool += QLatin1String(" -protected");
 
-    jarSignerTool += QString::fromLatin1(" %1 \"%2\"")
-            .arg(options.outputDirectory
+    jarSignerTool += QString::fromLatin1(" %1 %2")
+            .arg(shellQuote(options.outputDirectory
                  + QLatin1String("/bin/")
                  + apkName(options)
-                 + QLatin1String("-unsigned.apk"))
-            .arg(options.keyStoreAlias);
+                 + QLatin1String("-unsigned.apk")))
+            .arg(shellQuote(options.keyStoreAlias));
 
     FILE *jarSignerCommand = openProcess(jarSignerTool);
     if (jarSignerCommand == 0) {
@@ -1942,21 +2094,27 @@ bool signPackage(const Options &options)
 #endif
 
     if (!QFile::exists(zipAlignTool)) {
-        fprintf(stderr, "zipalign tool not found: %s\n", qPrintable(zipAlignTool));
-        return false;
+        zipAlignTool = options.sdkPath + QLatin1String("/build-tools/") + options.sdkBuildToolsVersion + QLatin1String("/zipalign");
+#if defined(Q_OS_WIN32)
+        zipAlignTool += QLatin1String(".exe");
+#endif
+        if (!QFile::exists(zipAlignTool)) {
+            fprintf(stderr, "zipalign tool not found: %s\n", qPrintable(zipAlignTool));
+            return false;
+        }
     }
 
-    zipAlignTool = QString::fromLatin1("\"%1\"%2 -f 4 %3 %4")
-            .arg(zipAlignTool)
+    zipAlignTool = QString::fromLatin1("%1%2 -f 4 %3 %4")
+            .arg(shellQuote(zipAlignTool))
             .arg(options.verbose ? QString::fromLatin1(" -v") : QString())
-            .arg(options.outputDirectory
+            .arg(shellQuote(options.outputDirectory
                  + QLatin1String("/bin/")
                  + apkName(options)
-                 + QLatin1String("-unsigned.apk "))
-            .arg(options.outputDirectory
+                 + QLatin1String("-unsigned.apk")))
+            .arg(shellQuote(options.outputDirectory
                  + QLatin1String("/bin/")
                  + apkName(options)
-                 + QLatin1String(".apk"));
+                 + QLatin1String(".apk")));
 
     FILE *zipAlignCommand = openProcess(zipAlignTool);
     if (zipAlignCommand == 0) {
@@ -2015,7 +2173,7 @@ bool deployAllToLocalTmp(const Options &options)
 {
     FILE *adbCommand = runAdb(options,
                               QString::fromLatin1(" push %1 /data/local/tmp/qt/")
-                              .arg(options.temporaryDirectoryName));
+                              .arg(shellQuote(options.temporaryDirectoryName)));
     if (adbCommand == 0)
         return false;
 
