@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
@@ -66,12 +66,17 @@
 #include <QtCore/QStandardPaths>
 #include <QtCore/QTextStream>
 #include <QtCore/QTimer>
+#include <QtCore/QBuffer>
+#include <QtCore/QLibraryInfo>
+#include <QtCore/QFileInfo>
+#include <QtCore/QDir>
 
 #include <QtWidgets/QAction>
 #include <QtWidgets/QComboBox>
 #include <QtWidgets/QDesktopWidget>
 #include <QtWidgets/QDockWidget>
 #include <QtGui/QFontDatabase>
+#include <QtGui/QImageReader>
 #include <QtWidgets/QFileDialog>
 #include <QtWidgets/QLabel>
 #include <QtWidgets/QLayout>
@@ -93,6 +98,8 @@
 
 QT_BEGIN_NAMESPACE
 
+enum { warnAboutMissingModules = 0 };
+
 MainWindow::MainWindow(CmdLineParser *cmdLine, QWidget *parent)
     : QMainWindow(parent)
     , m_bookmarkWidget(0)
@@ -162,8 +169,8 @@ MainWindow::MainWindow(CmdLineParser *cmdLine, QWidget *parent)
     openPagesDock->setWidget(openPagesManager->openPagesWidget());
     addDockWidget(Qt::LeftDockWidgetArea, openPagesDock);
 
-    connect(m_centralWidget, SIGNAL(addBookmark(QString, QString)),
-        bookMarkManager, SLOT(addBookmark(QString, QString)));
+    connect(m_centralWidget, SIGNAL(addBookmark(QString,QString)),
+        bookMarkManager, SLOT(addBookmark(QString,QString)));
     connect(bookMarkManager, SIGNAL(escapePressed()), this,
             SLOT(activateCurrentCentralWidgetTab()));
     connect(bookMarkManager, SIGNAL(setSource(QUrl)), m_centralWidget,
@@ -189,9 +196,14 @@ MainWindow::MainWindow(CmdLineParser *cmdLine, QWidget *parent)
     setWindowTitle(windowTitle.isEmpty() ? defWindowTitle : windowTitle);
     QByteArray iconArray = helpEngineWrapper.applicationIcon();
     if (iconArray.size() > 0) {
-        QPixmap pix;
-        pix.loadFromData(iconArray);
-        QIcon appIcon(pix);
+        QBuffer buffer(&iconArray);
+        QImageReader reader(&buffer);
+        QIcon appIcon;
+        do {
+            QPixmap pix;
+            pix.convertFromImage(reader.read());
+            appIcon.addPixmap(pix);
+        } while (reader.jumpToNextImage());
         qApp->setWindowIcon(appIcon);
     } else {
         QIcon appIcon(QLatin1String(":/qt-project.org/assistant/images/assistant-128.png"));
@@ -380,12 +392,14 @@ static const char *docs[] = {
     "qtdbus",
     "qtdesigner",
     "qtdoc",
+    "qtenginio",
     "qtgraphicaleffects",
     "qtgui",
     "qthelp",
     "qtimageformats",
     "qtlinguist",
     "qtlocation",
+    "qtmacextras",
     "qtmultimedia",
     "qtmultimediawidgets",
     "qtnfc",
@@ -414,20 +428,42 @@ static const char *docs[] = {
     "qtquickcontrolsstyles",
     "qtquickdialogs",
     "qtquicklayouts",
+    "qtwebsockets",
     "qtwinextras"
 };
 
+static QStringList newQtDocumentation()
+{
+    QStringList result;
+    const QDir docDirectory(QLibraryInfo::location(QLibraryInfo::DocumentationPath));
+    const QFileInfoList entries = docDirectory.entryInfoList(QStringList(QStringLiteral("*.qch")),
+                                                             QDir::Files, QDir::Name);
+    if (!entries.isEmpty()) {
+        result.reserve(entries.size());
+        foreach (const QFileInfo &fi, entries)
+            result.append(fi.baseName());
+        return result;
+    }
+    if (warnAboutMissingModules)
+        qWarning() << "No documentation found in " << QDir::toNativeSeparators(docDirectory.absolutePath());
+    const int docCount = int(sizeof(docs) / sizeof(docs[0]));
+    result.reserve(docCount);
+    for (int d = 0; d < docCount; ++d)
+        result.append(QLatin1String(docs[d]));
+    return result;
+}
+
 void MainWindow::lookForNewQtDocumentation()
 {
-    enum { warnAboutMissingModules = 0 };
     TRACE_OBJ
     HelpEngineWrapper &helpEngine = HelpEngineWrapper::instance();
 
-    const int docCount = int(sizeof(docs) / sizeof(docs[0]));
+    const QStringList docs = newQtDocumentation();
+    const int docCount = docs.size();
     QList<QtDocInstaller::DocInfo> qtDocInfos;
     qtDocInfos.reserve(docCount);
     for (int d = 0; d < docCount; ++d) {
-        const QString doc = QLatin1String(docs[d]);
+        const QString &doc = docs.at(d);
         const QtDocInstaller::DocInfo docInfo(doc, helpEngine.qtDocInfo(doc));
         qtDocInfos.append(docInfo);
         if (warnAboutMissingModules && (docInfo.second.isEmpty() || docInfo.second.first().isEmpty()))
@@ -439,8 +475,8 @@ void MainWindow::lookForNewQtDocumentation()
         SLOT(qtDocumentationInstalled()));
     connect(m_qtDocInstaller, SIGNAL(qchFileNotFound(QString)), this,
             SLOT(resetQtDocInfo(QString)));
-    connect(m_qtDocInstaller, SIGNAL(registerDocumentation(QString, QString)),
-            this, SLOT(registerDocumentation(QString, QString)));
+    connect(m_qtDocInstaller, SIGNAL(registerDocumentation(QString,QString)),
+            this, SLOT(registerDocumentation(QString,QString)));
     if (helpEngine.qtDocInfo(QLatin1String("qt")).count() != 2)
         statusBar()->showMessage(tr("Looking for Qt Documentation..."));
     m_qtDocInstaller->installDocs();
@@ -868,7 +904,7 @@ void MainWindow::showAboutDialog()
         aboutDia.setText(tr("<center>"
             "<h3>%1</h3>"
             "<p>Version %2</p></center>"
-            "<p>Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).</p>")
+            "<p>Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).</p>")
             .arg(tr("Qt Assistant")).arg(QLatin1String(QT_VERSION_STR)),
             resources);
         QLatin1String path(":/qt-project.org/assistant/images/assistant-128.png");
