@@ -85,7 +85,9 @@
 #include <QtGui/QImage>
 #include <QtGui/QPixmap>
 #include <QtWidgets/QMdiSubWindow>
+#ifndef QT_NO_PRINTER
 #include <QtPrintSupport/QPrintDialog>
+#endif
 #include <QtGui/QPainter>
 #include <QtGui/QTransform>
 #include <QtGui/QCursor>
@@ -1044,7 +1046,7 @@ QAction *QDesignerActions::minimizeAction() const
 void QDesignerActions::showDesignerHelp()
 {
     QString url = AssistantClient::designerManualUrl();
-    url += QStringLiteral("qtdesigner-index.html");
+    url += QStringLiteral("qtdesigner-manual.html");
     showHelp(url);
 }
 
@@ -1376,7 +1378,7 @@ void QDesignerActions::formWindowCountChanged()
 
 void QDesignerActions::printPreviewImage()
 {
-#ifndef QT_NO_PRINTER
+#if !defined(QT_NO_PRINTER) && !defined(QT_NO_PRINTDIALOG)
     QDesignerFormWindowInterface *fw = core()->formWindowManager()->activeFormWindow();
     if (!fw)
         return;
