@@ -44,8 +44,6 @@
 
 #include <QtDesigner/extension.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QAction;
@@ -67,6 +65,4 @@ inline QAction *QDesignerTaskMenuExtension::preferredEditAction() const
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // TASKMENU_H
