@@ -174,9 +174,6 @@ static inline QString stackedClassName(QStackedWidget *w)
 
 void QStackedWidgetPreviewEventFilter::updateButtonToolTip(QObject *o)
 {
-    QString className = QStringLiteral("Stacked widget");
-    if (const QDesignerFormWindowInterface *fw = QDesignerFormWindowInterface::findFormWindow(m_stackedWidget))
-        className = qdesigner_internal::WidgetFactory::classNameOf(fw->core(), m_stackedWidget);
     if (o == m_prev) {
         const QString msg = tr("Go to previous page of %1 '%2' (%3/%4).").arg(stackedClassName(m_stackedWidget)).arg(m_stackedWidget->objectName()).arg(m_stackedWidget->currentIndex() + 1).arg(m_stackedWidget->count());
         m_prev->setToolTip(msg);
