@@ -45,8 +45,6 @@
 #include <QtDesigner/extension.h>
 #include <QtCore/QObject>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 class QWidget;
@@ -77,6 +75,4 @@ Q_DECLARE_EXTENSION_INTERFACE(QDesignerContainerExtension, "org.qt-project.Qt.De
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // CONTAINER_H
