@@ -50,6 +50,7 @@
 #include <ui4_p.h>
 
 #include <QtCore/qdebug.h>
+#include <QtCore/QDataStream>
 #include <QtWidgets/QAction>
 #include <QtWidgets/QActionGroup>
 #include <QtWidgets/QApplication>
@@ -74,6 +75,22 @@ Q_GLOBAL_STATIC(widget_map, g_widgets)
 class QUiLoader;
 class QUiLoaderPrivate;
 
+#ifndef QT_NO_DATASTREAM
+// QUiTranslatableStringValue must be streamable since they become part of the QVariant-based
+// mime data when dragging items in views with QAbstractItemView::InternalMove.
+QDataStream &operator<<(QDataStream &out, const QUiTranslatableStringValue &s)
+{
+    out << s.comment() << s.value();
+    return out;
+}
+
+QDataStream &operator>>(QDataStream &in, QUiTranslatableStringValue &s)
+{
+    in >> s.m_comment >> s.m_value;
+    return in;
+}
+#endif // QT_NO_DATASTREAM
+
 #ifdef QFORMINTERNAL_NAMESPACE
 namespace QFormInternal
 {
@@ -401,8 +418,6 @@ static QString convertTranslatable(const DomProperty *p, const QByteArray &class
 
 void FormBuilderPrivate::applyProperties(QObject *o, const QList<DomProperty*> &properties)
 {
-    typedef QList<DomProperty*> DomPropertyList;
-
     QFormBuilder::applyProperties(o, properties);
 
     if (!m_trwatch)
@@ -622,6 +637,13 @@ QUiLoader::QUiLoader(QObject *parent)
 {
     Q_D(QUiLoader);
 
+#ifndef QT_NO_DATASTREAM
+    static int metaTypeId = 0;
+    if (!metaTypeId) {
+        metaTypeId = qRegisterMetaType<QUiTranslatableStringValue>("QUiTranslatableStringValue");
+        qRegisterMetaTypeStreamOperators<QUiTranslatableStringValue>("QUiTranslatableStringValue");
+    }
+#endif // QT_NO_DATASTREAM
     d->builder.loader = this;
 
     QStringList paths;
