@@ -43,7 +43,6 @@
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
-#include <QtCore/QTextCodec>
 
 #include <QtWidgets/QMessageBox>
 #include <QtGui/QPainter>
@@ -243,7 +242,6 @@ bool DataModel::load(const QString &fileName, bool *langGuessed, QWidget *parent
     }
 
     m_srcFileName = fileName;
-    m_codecName = tor.codecName();
     m_relativeLocations = (tor.locationsType() == Translator::RelativeLocations);
     m_extra = tor.extras();
     m_contextList.clear();
@@ -268,7 +266,7 @@ bool DataModel::load(const QString &fileName, bool *langGuessed, QWidget *parent
             MessageItem tmp(msg);
             if (msg.type() == TranslatorMessage::Finished)
                 c->incrementFinishedCount();
-            if (msg.type() != TranslatorMessage::Obsolete) {
+            if (msg.type() == TranslatorMessage::Unfinished) {
                 doCharCounting(tmp.text(), m_srcWords, m_srcChars, m_srcCharsSpc);
                 doCharCounting(tmp.pluralText(), m_srcWords, m_srcChars, m_srcCharsSpc);
                 c->incrementNonobsoleteCount();
@@ -336,15 +334,15 @@ bool DataModel::save(const QString &fileName, QWidget *parent)
 
     tor.setLanguageCode(Translator::makeLanguageCode(m_language, m_country));
     tor.setSourceLanguageCode(Translator::makeLanguageCode(m_sourceLanguage, m_sourceCountry));
-    tor.setCodecName(m_codecName);
     tor.setLocationsType(m_relativeLocations ? Translator::RelativeLocations
                                              : Translator::AbsoluteLocations);
     tor.setExtras(m_extra);
     ConversionData cd;
+    tor.normalizeTranslations(cd);
     bool ok = tor.save(fileName, cd, QLatin1String("auto"));
     if (ok)
         setModified(false);
-    else
+    if (!cd.error().isEmpty())
         QMessageBox::warning(parent, QObject::tr("Qt Linguist"), cd.error());
     return ok;
 }
